@@ -956,7 +956,11 @@ new_viewer(int fd, unsigned char *addr, int pid, char *filename,
     v->title = malloc(strlen(filename) + 8);
     strcpy(v->title, v->load_grays ? "gray: " : "RGB: ");
     strcat(v->title, filename);
-    v->filename = strrchr(v->title, '/');
+    if (NULL != (v->filename = strrchr(v->title, '/'))) {
+	v->filename++;
+    } else {
+	v->filename = v->title + (v->load_grays ? 6 : 5);
+    }
     v->iproc = XtAppAddInput(app_context, fd, (XtPointer) XtInputReadMask,
 			     viewer_input, (XtPointer) v);
     v->busy = 1;
@@ -966,8 +970,10 @@ new_viewer(int fd, unsigned char *addr, int pid, char *filename,
 				  dpy,
 				  XtNtitle,
 			      get_string_resource(app_shell, "str_load"),
+				  XtNiconName,v->filename,
 				  XtNmaxWidth, v->width,
 				  XtNmaxHeight, v->height,
+				  XtNclientLeader, app_shell,
 				  NULL);
 
     XtOverrideTranslations(v->shell, XtParseTranslationTable
